# Changelog

## [Unreleased](https://github.com/kalbfuss/01memories/tree/HEAD)

[Full Changelog](https://github.com/kalbfuss/01memories/compare/v0.0.32...HEAD)

**Fixed bugs:**

- Display not turned off under Wayland [\#5](https://github.com/kalbfuss/01memories/issues/5)

## [v0.0.32](https://github.com/kalbfuss/01memories/tree/v0.0.32) (2025-01-06)

[Full Changelog](https://github.com/kalbfuss/01memories/compare/v0.0.31...v0.0.32)

**Fixed bugs:**

- Zoom animation of photos not stopped during pause [\#4](https://github.com/kalbfuss/01memories/issues/4)

## [v0.0.31](https://github.com/kalbfuss/01memories/tree/v0.0.31) (2024-10-03)

[Full Changelog](https://github.com/kalbfuss/01memories/compare/v0.0.30...v0.0.31)

## [v0.0.30](https://github.com/kalbfuss/01memories/tree/v0.0.30) (2024-09-28)

[Full Changelog](https://github.com/kalbfuss/01memories/compare/v0.0.28...v0.0.30)

## [v0.0.28](https://github.com/kalbfuss/01memories/tree/v0.0.28) (2024-08-11)

[Full Changelog](https://github.com/kalbfuss/01memories/compare/v0.0.27...v0.0.28)

## [v0.0.27](https://github.com/kalbfuss/01memories/tree/v0.0.27) (2024-06-22)

[Full Changelog](https://github.com/kalbfuss/01memories/compare/4b069219a79d710bb25499231f7f9c06f62290a5...v0.0.27)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
